unit TrainingPatternEditor;

// Neural MLP network
//
// (c)2003, TEDSoft GmbH, Bonn, Germany
//
// www.tedsoft.de, info@tedsoft.de
//
// Alle Rechte vorbehalten.
// 
// All rights reserved - unless granted by written agreement.
//
// It is not permitted to remove this notice.
//
// Free for noncommercial use.

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, TedNetUnit, DesignIntf, DesignEditors, StdCtrls;

type
  TTrainingpatternEditor = class (TPropertyEditor)
    public
      function GetValue: String; override;
      procedure SetValue(const value: String); override;
      function GetAttributes: TPropertyAttributes; override;
      procedure Edit; override;
    end;

   TTrainingPatternForm = class(TForm)
     TrainingDataOpenDialog: TOpenDialog;
     CloseButton: TButton;
     numberOfTrainValuesLabel: TLabel;
     loadDataButton: TButton;
     procedure FormDestroy(Sender: TObject);
     procedure FormCreate(Sender: TObject);
     procedure CloseButtonClick(Sender: TObject);
     procedure loadDataButtonClick(Sender: TObject);
     private
       FTrainingPattern: TTrainingPattern;
     public
       //import training pattern
       procedure SetTrainingPattern(const TrainingPatternIn: TTrainingPattern);
       //export training pattern
       function GetTrainingPattern(): TTrainingPattern;
     end;

procedure Register;

implementation

{$R *.dfm}

procedure TTrainingPatternForm.SetTrainingPattern
                            (const TrainingPatternIn: TTrainingPattern);
begin
  FTrainingPattern.assign(TrainingPatternIn);
end;

function TTrainingPatternForm.GetTrainingPattern(): TTrainingPattern;
begin
  Result := FTrainingPattern;
end;

procedure TTrainingPatternForm.FormDestroy(Sender: TObject);
begin
  FTrainingPattern.Free;
end;

{ TTrainingpatternEditor }
procedure TTrainingpatternEditor.Edit;
begin
  inherited;
  with TTrainingPatternForm.Create(nil) do
  try
    if NOT (GetComponent (0) is TTEDNet) then
      raise Exception.Create ('GetComponent (0) is not an TedNet.');
    SetTrainingPattern(TTrainingPattern(GetOrdValue));
    numberOfTrainValuesLabel.caption:='number of training values: '+
            IntToStr(GetTrainingPattern.getNumberOfTrainingValues);
    if ShowModal = mrOK then
    begin
      TTrainingPattern(GetOrdValue).assign(GetTrainingPattern);
    end;
  finally
    Release;
  end;
end;

function TTrainingPatternEditor.GetValue: String;
begin
  result:='(TTrainingPattern)';
end;

procedure TTrainingPatternEditor.SetValue(const value: String);
begin
end;

function TTrainingpatternEditor.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog,paReadOnly];
end;

procedure Register;
begin
  RegisterPropertyEditor (TypeInfo(TTrainingPattern), TTedNet,
      'TrainingPattern', TTrainingPatternEditor);
end;




procedure TTrainingPatternForm.FormCreate(Sender: TObject);
begin
  FTrainingPattern:= TTrainingPattern.create;
end;

procedure TTrainingPatternForm.CloseButtonClick(Sender: TObject);
begin
  ModalResult:=mrOK;
end;

procedure TTrainingPatternForm.loadDataButtonClick(Sender: TObject);
var
  numberOfTrainingValues: integer;
  doubles: TDoubleArray;
  trainingInit: boolean;
begin
  if trainingDataOpenDialog.execute then
  begin
    ParseTextFileIntoDoubles(trainingDataOpenDialog.FileName,
                                    doubles, numberOfTrainingValues);
    FTrainingPattern.SetPatternWithDoubles(doubles,numberOfTrainingValues,
                      trainingInit);
    if trainingInit then showMessage('TrainingPattern parsed');
    numberOfTrainValuesLabel.caption:='number of training values: '+
                IntToStr(FTrainingPattern.getNumberOfTrainingValues);
  end;
end;

end.
